/*
***************************************************************************
**                                                                       **
**	Restart manager  -  Extension for Pale Moon                          **
**                                                                       **
**	Options window assistive code                                        **
**                                                                       **
**	Copyright(C) 2018 by George Malamas                                  **
**                                                                       **
**	Free software for all people                                         **
**                                                                       **
**	Last edit: June 29, 2018                                             **
**                                                                       **
**	Release number: 2                                                    **
**                                                                       **
***************************************************************************
*/
/*
This code adapts our options dialog to each app version, set the state of some 
elements at the moment of dialog loading and during user input controls the state 
of some dependent check boxes.
*/
// "use strict";

var aChkbx = window.document.getElementById("askCheckbox");
var appVersion = parseFloat(Components.classes["@mozilla.org/xre/app-info;1"]
					.getService(Components.interfaces.nsIXULAppInfo).version);
if(appVersion <20 && appVersion >=3) { // Must be done at the beginning of loading!
 	aChkbx.setAttribute("preference", "ask2Pref");
};
var rChkbx = window.document.getElementById("restoreCheckbox");
var wChkbx = window.document.getElementById("warnOnCloseCheckbox");
var iconSelect = window.document.getElementById("iconSel");
var shortCutSet = window.document.getElementById("scSetUp-radios");
var vbxChkbxes = window.document.getElementById("4appVer20plus");
var warn2Chkbx = window.document.getElementById("warnOnClosePrvChkbox");
var invChkbx = window.document.getElementById("invCaches");
var hChkbx = window.document.getElementById("highlight");
var btnStylebox = window.document.getElementById("btnStyle-box");
var smallBtnSelBox = window.document.getElementById("smallBtnSel");
var smallBtnSelSep = window.document.getElementById("smallBtnSel-sep");
var shortcutVisState = window.document.getElementById("shortcutVis-state");
var shortcutState = window.document.getElementById("shortcut-state");
var txtField = window.document.getElementById("shortcut-char");
var txtFieldCurrentValue ="R";
var promptLabel = window.document.getElementById("scSetUp-label3");
var codeMonBox = window.document.getElementById("codeMon_hbox");
var scSetUpLabel1 = window.document.getElementById("scSetUp-label1");
var restmanRadioBtn3 = window.document.getElementById("restman-radioBtn3");
var restmanVersion = window.document.getElementById("restmanVersion");

function toggleRWState() {
	if(aChkbx.checked) {
		rChkbx.disabled = false;
		if(!rChkbx.checked) {
			rChkbx.click();
		};
	} else {
		if(rChkbx.checked) {
			rChkbx.click();
		};
		if(wChkbx.checked) {
			wChkbx.click();
		};
		rChkbx.disabled = true;
		wChkbx.disabled = true;
	};
};
function toggleWState() {
	if(!rChkbx.checked) {
		wChkbx.disabled = false;
		if(!wChkbx.checked) {
			wChkbx.click();
		};
	} else {
		if(wChkbx.checked) {
			wChkbx.click();
		};
		wChkbx.disabled = true;
	};
};
function toggleShortcutSetUpState() {
	if(_RestMan.appVer >=3) {
		var shortcutSetUp = window.document.getElementsByClassName("shortcutSetUp");
		if(!shortcutState.checked) {
			Array.forEach(shortcutSetUp, function(aState) {
				if(aState.disabled) {
					aState.disabled = false;
				};
			});
		} else if(shortcutState.checked) {
			Array.forEach(shortcutSetUp, function(aState) {
				if(!aState.disabled) {
					aState.disabled = true;
				};
			});
		};
	} else if(_RestMan.appVer <3) {
		if(!shortcutState.checked) {
			window.document.getElementById("scSetUp-label1").disabled = false;
			shortCutSet.disabled = false;
			window.document.getElementById("scSetUp-label2").disabled = false;
			promptLabel.disabled = false;
			shortcutVisState.disabled = false;
			txtField.disabled = false;
		} else if(shortcutState.checked) {
			window.document.getElementById("scSetUp-label1").disabled = true;
			shortCutSet.disabled = true;
			window.document.getElementById("scSetUp-label2").disabled = true;
			promptLabel.disabled = true;
			txtField.disabled = true;
			shortcutVisState.disabled = true;
		};
	};
};
function toggleHhighlightState() {
	if(invChkbx.checked) {
		hChkbx.disabled = false;
		if(!hChkbx.checked) {
			hChkbx.click();
		};
	} else {
		if(hChkbx.checked) {
			hChkbx.click();
		};
		hChkbx.disabled = true;
	};
};
function checkInput() { // We want to allow only letter character of any language. It's not
// easily possible ("\w" matches only latin characters). So, we exclude the numbers
// and some commonly used keyboard symbols.
	if(txtField.value == "" ||
		(/[\d!\u00a1@#$\u00a7%^&*()\\\/|\{\}\[\]\-_+=,.?]/).test(txtField.value) ||
		(/[\u00bf;:'\u0384"~\u2022<>\u00ab\u00bb\u00a6\u00ac]/).test(txtField.value) ||
		(/[\u20a4\u20a3\u00a5\u00a4\u00a3\u00a2\u20ac\u00b7\t ]/).test(txtField.value)) {
		var blinks = 0;
		function blinkLabelRestoreValue(aState) {
			if(blinks < 5 && aState == "set") {
				promptLabel.style.setProperty("color", "red", "");
				blinks++;
				window.setTimeout(function() {
					blinkLabelRestoreValue("reset");
				}, 250);
			};
			if(aState == "reset") {
				promptLabel.style.removeProperty("color");
				if(blinks == 5) {
					txtField.value = txtFieldCurrentValue;
					txtField.select();
					return;
				};
				window.setTimeout(function() {
					blinkLabelRestoreValue("set");
				}, 250);
			};
		};
		blinkLabelRestoreValue("set");
		return false;
	};
	if(txtField.value.toLocaleUpperCase() == txtFieldCurrentValue) {
		txtField.value = txtFieldCurrentValue;
		window.setTimeout(function() {
			txtField.select();
		}, 1500);
		return false;
	};
	window.setTimeout(function() {
		txtField.select();
	}, 2500);
	return true;
};
function setOnLoadState() {
	txtFieldCurrentValue = txtField.value;
	var acceptButton = window.document.documentElement.getButton("accept");
	if(acceptButton.hidden) { // Some app versions ignore the attribute "buttons"
		// in "prefwindow" type dialogs, for some type of buttons, e.g. "accept".. (Relation to "browser.preferences.instantApply"..?)
		acceptButton.removeAttribute("hidden");
	};
	if(scSetUpLabel1.getAttribute("chromedir") == "rtl") {
		scSetUpLabel1.value = "+ Cmd\\Ctrl";
		restmanRadioBtn3.label = "Option\\Alt";
		restmanRadioBtn3.parentNode.insertBefore(restmanRadioBtn3, restmanRadioBtn3.nextSibling);
		if(_RestMan.appVer >=3) { // AppVer 3+ put in front of the text the last "/", in RTL locales.
			restmanVersion.setAttribute("tooltiptext", " /https://addons.palemoon.org/addon/restart-manager ");
		};
	};
	if(_RestMan.codMonChkBoxHid) {
		codeMonBox.hidden = true;
	};
	if(invChkbx.checked) {
		hChkbx.disabled = false;
	} else {
		hChkbx.disabled = true;
	};
	if(_RestMan.appVer >=20) {
		if(aChkbx.checked) {
			rChkbx.disabled = false;
			if(rChkbx.disabled || rChkbx.checked) {
				wChkbx.disabled = true;
			};
		} else {
			rChkbx.disabled = true;
			wChkbx.disabled = true;
		};
		var widthValue = window.getComputedStyle(wChkbx).getPropertyValue("width");
		warn2Chkbx.style.setProperty("width", widthValue);
		warn2Chkbx.removeAttribute("hidden");
		if(_RestMan.codeMonitoring) {
			window.setTimeout(function() {
				alert("Computed width of third checkbox (Warn me...)\n+ its label:"
					+ "\n\n" + widthValue);
			}, 600);
		};
	} else if(_RestMan.appVer <20) {
		aChkbx.removeAttribute("oncommand");
		vbxChkbxes.parentNode.removeChild(vbxChkbxes);
	};
	if(_RestMan.appVer <4) {
		btnStylebox.parentNode.removeChild(btnStylebox);
		smallBtnSelSep.parentNode.removeChild(smallBtnSelSep);
		smallBtnSelBox.parentNode.removeChild(smallBtnSelBox);
		invChkbx.setAttribute("label", "[ InvalidateCachesOnRestart ]");
		invChkbx.style.removeProperty("height");
	};
	if(_RestMan.appVer >=3) {
		var shortcutSetUp = window.document.getElementsByClassName("shortcutSetUp");
		if(shortcutState.checked) {
			Array.forEach(shortcutSetUp, function(aState) {
				aState.disabled = true;
			});
		};
	} else if(_RestMan.appVer <3) {
		if(shortcutState.checked) {
			window.document.getElementById("scSetUp-label1").disabled = true;
			shortCutSet.disabled = true;
			window.document.getElementById("scSetUp-label2").disabled = true;
			window.document.getElementById("scSetUp-label3").disabled = true;
			txtField.disabled = true;
			shortcutVisState.disabled = true;
		};
	};
	if(_RestMan.appVer <3.5) {
		iconSelect.setAttribute("style", "-moz-margin-start: 0.25em;");
	};
	if(_RestMan.appVer >3 &&
		_RestMan.appInfo.QueryInterface(Components.interfaces.nsIXULRuntime).OS !=="WINNT") {
		iconSelect.setAttribute("style", "-moz-margin-start: -0.035em;");
	};
};
function openHostPage(extPageUrl) {
	// var consoleServ = cc["@mozilla.org/consoleservice;1"].getService(ci.nsIConsoleService);
	var winOpener = window.opener.document.documentElement.getAttribute("windowtype");
	if(winOpener == "navigator:browser") { //We use this method because some extensions
		//override globally in the browser window the default behavior of "openURL()",
		//causing links to open in the current tab.
		window.opener.gBrowser.selectedTab = window.opener.gBrowser.addTab(extPageUrl); // consoleServ.logStringMessage("winOpener = " + winOpener);
	} else if(winOpener == "Addons:Manager" || winOpener == "Extension:Manager") {
		window.opener.openURL(extPageUrl); // consoleServ.logStringMessage("winOpener = " + winOpener);
	};
};
function sendMail(address) {
	if(_RestMan.appVer >2) {
		window.opener.openURL(address);
	} else {
		window.opener.gBrowser.loadOneTab(address, null, null, null, false);
	};
};
